@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2023 -- leonerd@leonerd.org.uk
 
-package meta 0.002;
+package meta 0.003;
 
 use v5.14;
 use warnings;
@@ -42,6 +42,12 @@ consistent place to add new abilities, such as more APIs for inspection and
 alteration of internal structures, metaprogramming around the new C<'class'>
 feature, and other such uses.
 
+This module should be considered B<experimental>; no API stability guarantees
+are made at this time. Behaviour may be added, altered, or removed in later
+versions. Once a workable API shape has been found, it is hoped that this
+module will eventually become dual-life and shipped as part of Perl core, as
+the implementation for PPC 0022. See the link in the L</SEE ALSO> section.
+
 =cut
 
 =head1 FUNCTIONS
@@ -255,6 +261,12 @@ methods, fields.
 
 =cut
 
+=head1 SEE ALSO
+
+L<PPC 0022 "metaprogramming"|https://github.com/Perl/PPCs/blob/main/ppcs/ppc0022-metaprogramming.md>
+
+=cut
+
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
